%This matlab file reads the data generated by the Analysis Sequences
%in the DemoModels and plots the comparisons between Coustyx results 
%and Analytical results.

%********************************************************************
%Compare results from coustyx and analytical solutions for 
%Far-field radiated by a circular piston in a infinite rigid baffle

%********************************************************************
%Input:
%  Run the following Analysis Sequences in the Demo Model,
%  before running this matlab script. 
%   (1) RunValidation - FMM
%********************************************************************
resultsFMM = load('validation_results_fmm.txt');

%  Each *.txt results file has 5 columns, where
%    results(:,1) = theta, 0<=theta<=2PI
%    results(:,2) = Real part of coustyx field point pressure
%    results(:,3) = Imaginary part of coustyx field point pressure
%    results(:,4) = Real part of analytical pressure
%    results(:,5) = Imaginary part of analytical pressure

%********************************************************************

%********************************************************************
%Output:
%  (1) plot 1: Plots comparisons between FMM and Analytical results
%********************************************************************

%Acoustic medium properties:
%  rho_o = medium density of air = 1.21 kg.m^3
%  c = speed of sound = 343 m/s
%  P0 = amplitude of the incident plane wave = 1 pa
rho_o = 1.21;
c = 343;
u0 = 1;

%********************************************************************
xfmm = (abs(resultsFMM(:,2)+i*resultsFMM(:,3)).*cos(resultsFMM(:,1)));
yfmm = (abs(resultsFMM(:,2)+i*resultsFMM(:,3)).*sin(resultsFMM(:,1)));
xanaly = (abs(resultsFMM(:,4)+i*resultsFMM(:,5)).*cos(resultsFMM(:,1)));
yanaly = (abs(resultsFMM(:,4)+i*resultsFMM(:,5)).*sin(resultsFMM(:,1)));


%********************************************************************
% Plot FMM and Analytical results on a plot showing angular 
% distribution of pressure amplitudes.
% Note the radius at any point on the graph is equal to the amplitude
% of pressure.
%********************************************************************
figure;
plot(xfmm, yfmm, 'k-', xanaly, yanaly, 'ro');
xlabel('z (m)');
ylabel('y (m)');
% xlim([-1.6 1.6]);
% ylim([-1.6 1.6]);
legend('Coustyx-FMM','Analytical');
title('Field point pressures - Amplitude at r=100m on x=0 plane');

% matFMM = [xfmm yfmm xanaly yanaly];
% save results_abs_fmm_ka5.txt matFMM -ASCII







